@@ -52,7 +52,6 @@ def main():
         "loggers": {
             "": {"level": "DEBUG", "handlers": ["console"]},
             "wi1_bot": {"level": "DEBUG", "handlers": [], "propagate": True},
-            "websockets": {"level": "INFO", "handlers": [], "propagate": True},
         },
     }
 
@@ -60,7 +59,7 @@ def main():
 
     webhook.start()
 
-    t = Transcoder(ws=False)
+    t = Transcoder()
     t.start()
 
     try:
